CANYON_BLOCKS = {
    'RoadRaceStraight': 1,
    'RoadRaceStraightScreen': 2,
    'RoadRaceStraightOffice': 3,
    'RoadRaceStraightWindows': 4,
    'RoadRaceStraightJump': 5,
    'RoadRaceSwitchStraight1x1Mirror': 6,
    'RoadRaceSwitchStraight1x1': 7,
    'RoadRaceCornerIn': 8,
    'RoadRaceCornerInScreen': 9,
    'RoadRaceCornerOut': 10,
    'RoadRaceGTCurve2In': 11,
    'RoadRaceGTCurve2Out': 12,
    'RoadRaceSlopeBaseGTCurve2In': 13,
    'RoadRaceSlopeBaseGTCurve2InMirror': 14,
    'RoadRaceSlopeBaseGTCurve2Out': 15,
    'RoadRaceSlopeBaseGTCurve2OutMirror': 16,
    'RoadRaceCheckpointMirror': 17,
    'RoadRaceCheckpoint': 18,
    'RoadRaceStartMirror': 19,
    'RoadRaceStart': 20,
    'RoadRaceFinish': 21,
    'RoadRaceFinishMirror': 22,
    'RoadRaceMultilapMirror': 23,
    'RoadRaceMultilap': 24,
    'RoadRaceTurboMirror': 25,
    'RoadRaceTurbo': 26,
    'RoadRaceTurbo2Mirror': 27,
    'RoadRaceTurbo2': 28,
    'RoadRaceFWMirror': 29,
    'RoadRaceFW': 30,
    'RoadRaceSlopeBase1': 31,
    'RoadRaceSlopeBase1Mirror': 32,
    'RoadRaceSlopeBase2': 33,
    'RoadRaceSlopeBase2Mirror': 34,
    'RoadRaceSlopeStaight': 35,
    'RoadRaceSlopeStaightMirror': 36,
    'RoadRaceSwitchSlopeStraight1x1Mirror': 37,
    'RoadRaceSwitchSlopeStraight1x1': 38,
    'RoadRaceBiSlopeStart': 39,
    'RoadRaceBiSlopeStartMirror': 40,
    'RoadRaceBiSlopeEnd': 41,
    'RoadRaceBiSlopeEndMirror': 42,
    'RoadRaceSlopeCheckpointUp': 43,
    'RoadRaceSlopeCheckpointUpMirror': 44,
    'RoadRaceSlopeCheckpointDown': 45,
    'RoadRaceSlopeCheckpointDownMirror': 46,
    'RoadRaceSlopeTurboUp': 47,
    'RoadRaceSlopeTurboUpMirror': 48,
    'RoadRaceSlopeTurboDown': 49,
    'RoadRaceSlopeTurboDownMirror': 50,
    'RoadRaceSlopeTurbo2Up': 51,
    'RoadRaceSlopeTurbo2UpMirror': 52,
    'RoadRaceSlopeTurbo2Down': 53,
    'RoadRaceSlopeTurbo2DownMirror': 54,
    'RoadRaceSlopeFW': 55,
    'RoadRaceSlopeFWMirror': 56,
    'RoadRaceTiltStraight': 57,
    'RoadRaceTiltCorner': 58,
    'RoadRaceTiltGTCurve2In': 59,
    'RoadRaceTiltCornerInUp': 60,
    'RoadRaceTiltCornerInUpMirror': 61,
    'RoadRaceTiltCornerOutDown': 62,
    'RoadRaceTiltCornerOutDownMirror': 63,
    'RoadRaceTiltGTCurve2InUp': 64,
    'RoadRaceTiltGTCurve2InUpMirror': 65,
    'RoadRaceTiltGTCurve2OutDown': 66,
    'RoadRaceTiltGTCurve2OutDownMirror': 67,
    'RoadRaceTiltCheckpoint': 68,
    'RoadRaceTiltCheckpointMirror': 69,
    'RoadRaceTiltTurbo': 70,
    'RoadRaceTiltTurboMirror': 71,
    'RoadRaceTiltTurbo2': 72,
    'RoadRaceTiltTurbo2Mirror': 73,
    'RoadRaceTiltFW': 74,
    'RoadRaceTiltToRoadRacex2': 75,
    'RoadRaceTiltToRoadRacex2Mirror': 76,
    'RoadRaceTiltToRoadRaceDiagIn': 77,
    'RoadRaceTiltToRoadRaceDiagInMirror': 78,
    'RoadRaceTiltToRoadRaceDiagOut': 79,
    'RoadRaceTiltToRoadRaceDiagOutMirror': 80,
    'RoadRaceToRoadMainA': 81,
    'RoadRaceToRoadMainMirrorA': 82,
    'RoadRaceToArena': 83,
    'RoadRaceToArenaMirror': 84,
    'ArenaSimpleBase': 85,
    'ArenaSimpleBaseNoPillar': 86,
    'ArenaBaseOut': 87,
    'ArenaSimpleDiag': 88,
    'ArenaSlopeBase': 89,
    'ArenaSlopeBase2': 90,
    'ArenaSlopeStart': 91,
    'ArenaSlopeStraight': 92,
    'ArenaSlopeEnd': 93,
    'ArenaBiSlopeStart': 94,
    'ArenaBiSlopeStraight': 95,
    'ArenaBiSlopeEnd': 96,
    'ArenaCheckpointBase': 97,
    'ArenaCheckpointSlopeStraightUp': 98,
    'ArenaCheckpointSlopeStraightDown': 99,
    'ArenaCheckpointSlopeStraightLeftAir': 100,
    'ArenaCheckpointSlopeStraightRightAir': 101,
    'OffRoadCheckpoint': 102,
    'ArenaStart': 103,
    'ArenaFinish': 104,
    'ArenaMultilap': 105,
    'ArenaTurbo1': 106,
    'ArenaTurbo1SlopeUp': 107,
    'ArenaTurbo1SlopeDown': 108,
    'ArenaTurbo1SlopeLeft': 109,
    'ArenaTurbo1SlopeRight': 110,
    'ArenaTurbo2': 111,
    'ArenaTurbo2SlopeUp': 112,
    'ArenaTurbo2SlopeDown': 113,
    'ArenaTurbo2SlopeLeft': 114,
    'ArenaTurbo2SlopeRight': 115,
    'ArenaFreeWheeling': 116,
    'ArenaFWSlopeUD': 117,
    'ArenaFWSlopeLR': 118,
    'ArenaBridgeBase': 119,
    'ArenaBridgeBaseNoPillar': 120,
    'ArenaSimpleHalfBase': 121,
    'ArenaSimpleHalfBaseCornerIn': 122,
    'ArenaSimpleHalfBaseCornerOut': 123,
    'ArenaRamp': 124,
    'ArenaFloodLightBaseU': 125,
    'ArenaFloodLightBaseCeilingA': 126,
    'ArenaScreenBase2x1': 127,
    'DecoLightArenaStraightLeft': 128,
    'DecoLightArenaStraightMed': 129,
    'DecoLightArenaStraightRight': 130,
    'ArenaTransitionFromRoadMain2': 131,
    'ArenaTransitionBridgeToRoadMain': 132,
    'ArenaTransitionToRoadMain': 133,
    'ArenaWallRideStraight': 134,
    'ArenaWallRideCorner': 135,
    'ArenaWallRideStraightGTCurve2': 136,
    'ArenaWallRideScreen2x1': 137,
    'ArenaWallRideCheckpoint_H': 138,
    'ArenaWallRideCheckpoint_V': 139,
    'ArenaWallRideStartStraight': 140,
    'ArenaWallRideStartCorner': 141,
    'ArenaWallRideStartGTCurve2': 142,
    'ArenaWallRideLoopStart': 143,
    'ArenaWallRideLoopEnd': 144,
    'ArenaWallRideTopStraight': 145,
    'ArenaWallRideTopCorner': 146,
    'ArenaWallRideTopGTCurve2': 147,
    'ArenaWallRideBorderStraight': 148,
    'ArenaWallRideBorderCorner': 149,
    'ArenaWallRideBorderGTCurve2': 150,
    'ArenaBorderStraightTower': 151,
    'ArenaBorderStraightA': 152,
    'ArenaBorderCornerTowerA': 153,
    'ArenaBorderCorner': 154,
    'ArenaBorderStraightPillarBank': 155,
    'ArenaBorderStraightPillarBankToArena': 156,
    'ArenaBorderCornerPillarBank': 157,
    'ArenaPasserelleStraight': 158,
    'ArenaRoadMainAndBank': 159,
    'ArenaTransitionFromRoadMainAndBankTunnel': 160,
    'ArenaTransitionFromRoadMainAndBankTunnelMirror': 161,
    'ArenaTransitionFromRoadMaindAndBank': 162,
    'ArenaTransitionFromRoadMaindAndBankMirror': 163,
    'ArenaHallwayStraight': 164,
    'ArenaHallway2WaysStraight': 165,
    'ArenaHallwayCorner': 166,
    'ArenaWallRideSlopeStraight': 167,
    'ArenaHallwaySlopeStraight': 168,
    'ArenaWallRideSlopeHallWay': 169,
    'ArenaLoopStraight1': 170,
    'ArenaLoopCornerOut': 171,
    'ArenaLoopStraightSlope': 172,
    'ArenaLoopStraightSlopeMirror': 173,
    'ArenaLoopStraightSlope2': 174,
    'ArenaLoopStraightSlope2Mirror': 175,
    'ArenaTunnelStraight': 176,
    'ArenaTunnelStraightOpen1Side': 177,
    'ArenaTunnelStraightOpen2Sides': 178,
    'ArenaTunnelStraightToOpen': 179,
    'ArenaTunnelCheckpoint': 180,
    'ArenaTunnelStraightOpen2SidesCheckpoint': 181,
    'ArenaTunnelCorner': 182,
    'ArenaTunnelGTCurve2': 183,
    'ArenaTunnelGTCurve3': 184,
    'ArenaTunnelGTDiag2': 185,
    'ArenaTunnelGTDiag2Mirror': 186,
    'ArenaTunnelGTDiag3': 187,
    'ArenaTunnelGTDiag3Mirror': 188,
    'ArenaTunnelSlopeBase': 189,
    'ArenaTunnelSlopeStart': 190,
    'ArenaTunnelSlopeStraight2': 191,
    'ArenaTunnelSlopeEnd': 192,
    'ArenaTunnelBiSlopeStart': 193,
    'ArenaTunnelSlopeStraight': 194,
    'ArenaTunnelBiSlopeEnd': 195,
    'ArenaTunnelSlopeBase2': 196,
    'ArenaTunnelSlopeBaseHole': 197,
    'ArenaTunnelSlopeBaseHole2': 198,
    'ArenaTunnelBanktoRoad': 199,
    'ArenaTunnelToArena': 200,
    'ArenaTunnelTransitionToBankLeft': 201,
    'ArenaTunnelTransitionToBankRight': 202,
    'ArenaTubeStraightA': 203,
    'ArenaTubeStraightB': 204,
    'TubeStraightScreenDown': 205,
    'TubeStraightScreenSide': 206,
    'TubeStraightScreenUp': 207,
    'TubeCrossAir': 208,
    'TubeCrossV': 209,
    'VStraight1Screen': 210,
    'TubeVStraight1AirA': 211,
    'TubeVStraight2AirA': 212,
    'TubeVStraight4AirA': 213,
    'ArenaTubeCorner': 214,
    'ArenaTubeGTCurve2': 215,
    'TubeGTCurve3': 216,
    'ToTubeVCornerAirAUp': 217,
    'TubeGTCurve2Up': 218,
    'ToTubeVCornerAirADown': 219,
    'TubeGTCurve2Down': 220,
    'TubeLoopRight': 221,
    'TubeLoopLeft': 222,
    'TubeCheckpoint': 223,
    'TubeCheckpointVAir': 224,
    'TubeFinish': 225,
    'TubeFreeWheeling': 226,
    'TubeToRoadMain': 227,
    'TubeToGround': 228,
    'TubeToArenaCenter': 229,
    'TubeStraightUnderground': 230,
    'TubeStraightScreenDownUnderground': 231,
    'TubeStraightScreenSideUnderground': 232,
    'TubeStraightScreenUpUnderground': 233,
    'TubeCrossUnderground': 234,
    'TubeCrossVUnderground': 235,
    'TubeVStraight1ScreenUnderground': 236,
    'TubeVStraight1Underground': 237,
    'TubeVStraight2Underground': 238,
    'ToTubeVStraight4UndergroundA': 239,
    'TubeCornerUnderground': 240,
    'ArenaTubeGTCurve2Underground': 241,
    'TubeGTCurve3Underground': 242,
    'TubeCornerUndergroundUp': 243,
    'ArenaTubeGTCurve2UndergroundUp': 244,
    'TubeCornerUndergroundDown': 245,
    'TubeGTCurve2UndergroundDown': 246,
    'TubeCheckpointUnderground': 247,
    'TubeCheckpointVUnderground': 248,
    'TubeFinishUnderground': 249,
    'TubeFreeWheelingUnderground': 250,
    'TubeLoopRightUnderground': 251,
    'TubeLoopLeftUnderground': 252,
    'TubeUndergroundDirtHill2': 253,
    'TubeUndergroundEntryDirtCliff4Low': 254,
    'TubeUndergroundEntryDirtCliff8Low': 255,
    'TubeUndergroundEntryDirtCliff8High': 256,
    'TubeUndergroundEntryWaterCliff12Low': 257,
    'TubeUndergroundEntryWaterCliff12Med': 258,
    'TubeUndergroundEntryWaterCliff12High': 259,
    'TubeUndergroundToRoadCave': 260,
    'RoadMain': 261,
    'RoadMainTreePineBigStraight': 262,
    'RoadMainJumpSmall': 263,
    'RoadMainStraightUp': 264,
    'RoadMainStraightDown': 265,
    'RoadMainSupport': 266,
    'RoadMainGTCurve2': 267,
    'RoadMainSlopeGTCurve2': 268,
    'RoadMainSlopeGTCurve2Mirror': 269,
    'RoadMainSlopeBase': 270,
    'RoadMainSlopeBase3': 271,
    'RoadMainBiSlopeStart': 272,
    'RoadMainSlopeStraight': 273,
    'RoadMainBiSlopeEnd': 274,
    'RoadMainGTDiag2X2A': 275,
    'RoadMainGTDiag2X2MirrorA': 276,
    'RoadMainGTDiag4X2': 277,
    'RoadMainGTDiag4X2Mirror': 278,
    'RoadMainGTDiag2X2Down': 279,
    'RoadMainGTDiag2X2DownMirror': 280,
    'RoadMainBridgeDirtHill2': 281,
    'RoadMainCheckpoint': 282,
    'RoadMainCheckpointUp': 283,
    'RoadMainBridgeDirtCliff4': 284,
    'RoadMainBridgeDirtCliff8': 285,
    'RoadMainCheckpointDown': 286,
    'RoadMainBridgeWaterCliff12': 287,
    'RoadMainStart': 288,
    'RoadMainFinish': 289,
    'RoadMainMultilap': 290,
    'RoadMainTurbo': 291,
    'RoadMainTurbo2': 292,
    'RoadMainFW': 293,
    'RoadHill2Straight': 294,
    'RoadHill2CornerIn': 295,
    'RoadHill2CornerOut': 296,
    'RoadHill2GTCurve2In': 297,
    'RoadHill2GTCurve2Out': 298,
    'RoadHill2CheckpointLeft': 299,
    'RoadHill2CheckpointRight': 300,
    'RoadMain2ToHill2Corner': 301,
    'RoadMain2ToHill2CornerMirror': 302,
    'Cliff12RoadHighStraight': 303,
    'Cliff12RoadHighBarrageLeft': 304,
    'Cliff12RoadHighBarrageRight': 305,
    'Cliff12RoadHighObstaclesRocks3x1': 306,
    'Cliff12RoadHighLoopHighLeft': 307,
    'Cliff12RoadHighLoopHighRight': 308,
    'Cliff12RoadHighBase1': 309,
    'RoadRaceBridgeDirtHill2': 310,
    'RoadRaceBridgeDirtHill2Mirror': 311,
    'Cliff12RoadHighCorner': 312,
    'RoadRaceBridgeDirtCliff4': 313,
    'RoadRaceBridgeDirtCliff4Mirror': 314,
    'RoadRaceBridgeDirtCliff8': 315,
    'Cliff12RoadHighGTCurve2In': 316,
    'RoadRaceBridgeDirtCliff8Mirror': 317,
    'Cliff12RoadHighGTCurve2Out': 318,
    'RoadRaceBridgeWaterCliff12': 319,
    'Cliff12RoadHighGTDiag3': 320,
    'RoadRaceBridgeWaterCliff12Mirror': 321,
    'Cliff12RoadHighGTDiag3Mirror': 322,
    'Cliff12RoadHighCheckpointLeft': 323,
    'Cliff12RoadHighCheckpointRight': 324,
    'Cliff12RoadHighTurboLeft': 325,
    'Cliff12RoadHighTurbo': 326,
    'Cliff12RoadHighTurboLeft2': 327,
    'Cliff12RoadHighTurbo2': 328,
    'Cliff12RoadHighFW': 329,
    'Cliff12RoadHighToRoadMainA': 330,
    'Cliff12RoadHighToRoadMainA_mirror': 331,
    'Cliff12RoadHighToRoadAirA': 332,
    'Cliff12RoadHighToRoadAirA_mirror': 333,
    'Cliff12RoadMedStraight': 334,
    'Cliff12RoadMedBarrageLeft': 335,
    'Cliff12RoadMedBarrageRight': 336,
    'Cliff12RoadMedObstaclesRocks3x1': 337,
    'Cliff12RoadMedLoopLeft': 338,
    'Cliff12RoadMedLoopRight': 339,
    'Cliff12RoadMedBase1': 340,
    'Cliff12RoadMedCorner': 341,
    'Cliff12RoadMedGTCurve2IN': 342,
    'Cliff12RoadMedGTCurve2OUT': 343,
    'Cliff12RoadMedGTDiag3': 344,
    'Cliff12RoadMedGTDiag3Mirror': 345,
    'Cliff12RoadMedCheckpointLeft': 346,
    'Cliff12RoadMedCheckpointRight': 347,
    'Cliff12RoadMedTurboLeft': 348,
    'Cliff12RoadMedTurbo': 349,
    'Cliff12RoadMedTurbo2Left': 350,
    'Cliff12RoadMedTurbo2': 351,
    'Cliff12RoadMedFW': 352,
    'Cliff12RoadHighToMedSlope3A': 353,
    'Cliff12RoadHighToMedSlope3A_Mirror': 354,
    'Cliff12RoadMedToRoadAir': 355,
    'Cliff12RoadMedToRoadAir_mirror': 356,
    'RoadCaveStraight': 357,
    'RoadCaveObstaclesYShaped2x1': 358,
    'RoadCaveCorner': 359,
    'RoadCaveGTCurve2': 360,
    'RoadCaveGTCurve3': 361,
    'RoadCaveGTDiag2': 362,
    'RoadCaveGTDiag2Mirror': 363,
    'RoadCaveGTDiag3': 364,
    'RoadCaveGTDiag3Mirror': 365,
    'RoadCaveSlopeBase': 366,
    'RoadCaveSlopeBase4': 367,
    'RoadCaveSlopeBaseGtCurve3': 368,
    'RoadCaveSlopeBaseGtCurve3Mirror': 369,
    'RoadCaveSlope2Base3x1': 370,
    'RoadCaveSlope2Start': 371,
    'RoadCaveSlope2Start2x2x1': 372,
    'RoadCaveSlope2Straight': 373,
    'RoadCaveSlope2End': 374,
    'RoadCaveSlope2End2x2x1': 375,
    'RoadCaveSlope2UTop': 376,
    'RoadCaveSlope2UBottom': 377,
    'RoadCaveSlope2Base3x1GT3Left': 378,
    'RoadCaveSlope2Base3x1GT3Right': 379,
    'RoadCaveCheckpoint': 380,
    'RoadCaveCheckpointSlope2Up': 381,
    'RoadCaveCheckpointSlope2Down': 382,
    'RoadCaveFinish': 383,
    'RoadCaveMultiLap': 384,
    'RoadCaveTurbo': 385,
    'RoadCaveTurboUp': 386,
    'RoadCaveTurboDown': 387,
    'RoadCaveTurbo2': 388,
    'RoadCaveTurbo2Up': 389,
    'RoadCaveTurbo2Down': 390,
    'RoadCaveFW': 391,
    'RoadCaveFWSlope2': 392,
    'RoadEntrySlopeStraight': 393,
    'RoadCaveEntryDirtHill2': 394,
    'RoadCaveEntryDirtCliff8Low': 395,
    'RoadCaveEntryDirtCliff4Low': 396,
    'RoadCaveEntryDirtCliff4Low2': 397,
    'RoadCaveEntryDirtCliff8Low2': 398,
    'RoadCaveEntryDirtCliff8High': 399,
    'RoadCaveEntryDirtCliff12Low': 400,
    'RoadCaveEntryDirtCliff12Med': 401,
    'RoadCaveEntryDirtCliff12High': 402,
    'RoadCaveDoubleStraight': 403,
    'RoadCaveDoubleObstacleRocks': 404,
    'RoadCaveDoubleObstacleJumpYShapedToGround': 405,
    'RoadCaveDoubleCross': 406,
    'RoadCaveDoubleObstacleJumpRoadCave': 407,
    'RoadCaveDoubleDeadend': 408,
    'RoadCaveDoubleCorner': 409,
    'RoadCaveDoubleGTCurve2': 410,
    'RoadCaveDoubleGTCurve3': 411,
    'RoadCaveDoubleDiag2x2': 412,
    'RoadCaveDoubleDiag2x2Mirror': 413,
    'RoadCaveDoubleDiag3x2': 414,
    'RoadCaveDoubleDiag3x2Mirror': 415,
    'RoadCaveDoubleSwitch2x1': 416,
    'RoadCaveDoubleSwitch3x1': 417,
    'RoadCaveDoubleSwitch3x1Mirror': 418,
    'RoadCaveDoubleSwitchDiag3x2': 419,
    'RoadCaveDoubleSwitchDiag3x2Mirror': 420,
    'RoadCaveDoubleCheckpoint': 421,
    'RoadCaveDoubleCheckpointCenter': 422,
    'RoadCaveDoubleCheckpointLeft': 423,
    'RoadCaveDoubleCheckpointRight': 424,
    'RoadCaveDoubleFinish': 425,
    'RoadCaveDoubleSlope2Base': 426,
    'RoadCaveDoubleSlope2Base2x1': 427,
    'RoadCaveDoubleSlope2Start': 428,
    'RoadCaveDoubleSlope2Straight': 429,
    'RoadCaveDoubleSlope2End': 430,
    'RoadCaveDoubleSlope2UTop': 431,
    'RoadCaveDoubleSlope2UBottom': 432,
    'RoadCaveDoubleToRoadCaveStraight': 433,
    'RoadCaveDoubleToRoadCaveCorner': 434,
    'RoadCaveDoubleToRoadCaveCornerMirror': 435,
    'RoadCaveDoubleToRoadCaveTShaped': 436,
    'DecoTreesBig1X1': 437,
    'DecoTreesMedium1X1': 438,
    'DecoRocksMedium1x1': 439,
    'DecoCactusMedium1X1': 440,
    'DecoBushesMedium1X1': 441,
    'Sequoias': 442,
    'DecoTerrainHD': 443,
    'ScreenBig2x1': 444,
    'Screen2x1StraightA': 445,
    'Screen2x1SupportStraightA': 446,
    'Screen2x1SupportCornerA': 447,
    'Screen2x1Small': 448,
    'Screen2x1SmallCenter': 449,
    'DecoTechnicsAntenna': 450,
    'Podium': 451,
    'DecoReffineryX1': 452,
    'DecoReffineryX2': 453,
    'DecoReffineryX4': 454,
    'DecoPipelineStraight': 455,
    'DecoPipelineCorner': 456,
    'DecoPipelineGTCurve2': 457,
    'DecoPipelineTshape': 458,
    'DecoPipelineSlope': 459,
    'PipelineDiag2x3Mirror': 460,
    'PipelineDiag2x3': 461,
}