STADIUM_BLOCKS = {
    'StadiumGrassClip': 1,
    'StadiumDirt': 2,
    'StadiumDirtBorder': 3,
    'StadiumWater': 4,
    'StadiumPool': 5,
    'StadiumRoadMain': 6,
    'StadiumRoadMainGTCurve2': 7,
    'StadiumRoadMainGTCurve3': 8,
    'StadiumRoadMainGTCurve4': 9,
    'StadiumRoadMainGTCurve5': 10,
    'StadiumLoopLeft': 11,
    'StadiumLoopRight': 12,
    'StadiumRoadMainCheckpoint': 13,
    'StadiumRoadMainStartLine': 14,
    'StadiumRoadMainFinishLine': 15,
    'StadiumRoadMainStartFinishLine': 16,
    'StadiumRoadMainTurbo': 17,
    'StadiumRoadMainTurboRoulette': 18,
    'StadiumRoadMainFW': 19,
    'StadiumGrassCheckpoint': 20,
    'StadiumHolePillar': 21,
    'StadiumHolePillar2Front': 22,
    'StadiumHolePillar2Line': 23,
    'StadiumHolePillar3': 24,
    'StadiumHole': 25,
    'StadiumRoadStretch': 26,
    'StadiumBump1': 27,
    'StadiumRamp': 28,
    'StadiumRampLow': 29,
    'StadiumRoadMainGTDiag2x2': 30,
    'StadiumRoadMainGTDiag2x2Mirror': 31,
    'StadiumRoadMainGTDiag3x2': 32,
    'StadiumRoadMainGTDiag3x2Mirror': 33,
    'StadiumRoadMainGTDiag4x3': 34,
    'StadiumRoadMainGTDiag4x3Mirror': 35,
    'StadiumRoadMainYShapedDiag2': 36,
    'StadiumRoadMainYShapedCurve2': 37,
    'StadiumRoadMainSlopeBase2': 38,
    'StadiumRoadMainSlopeBase': 39,
    'StadiumRoadMainSlopeStraight': 40,
    'StadiumRoadMainBiSlopeStart': 41,
    'StadiumRoadMainBiSlopeEnd': 42,
    'StadiumRoadMainSlopeUTop': 43,
    'StadiumRoadMainSlopeUBottom': 44,
    'StadiumRoadMainCheckpointUp': 45,
    'StadiumRoadMainCheckpointDown': 46,
    'StadiumRoadMainTurboUp': 47,
    'StadiumRoadMainTurboDown': 48,
    'StadiumRoadMainTurboRouletteDown': 49,
    'StadiumRoadMainTurboRouletteUp': 50,
    'StadiumHolePillarSlope': 51,
    'StadiumHoleSlope': 52,
    'StadiumRoadStretchSlope': 53,
    'StadiumBump1Slope': 54,
    'StadiumRoadMainGTDiag2x2Slope': 55,
    'StadiumRoadMainGTDiag2x2SlopeMirror': 56,
    'StadiumRoadMainGTDiag3x2Slope': 57,
    'StadiumRoadMainGTDiag3x2SlopeMirror': 58,
    'StadiumRoadMainGTDiag4x3Slope': 59,
    'StadiumRoadMainYShapedDiag2SlopeUp': 60,
    'StadiumRoadMainYShapedDiag2SlopeDown': 61,
    'StadiumRoadMainGTDiag4x3SlopeMirror': 62,
    'StadiumRoadTiltStraight': 63,
    'StadiumRoadTiltTransition1Left': 64,
    'StadiumRoadTiltTransition1Right': 65,
    'StadiumRoadTiltTransition2Left': 66,
    'StadiumRoadTiltTransition2Right': 67,
    'StadiumRoadTiltTransition2CurveLeft': 68,
    'StadiumRoadTiltTransition2CurveRight': 69,
    'StadiumRoadTiltTransition2DiagLeft': 70,
    'StadiumRoadTiltTransition2DiagRight': 71,
    'StadiumRoadMainCheckpointLeft': 72,
    'StadiumRoadMainCheckpointRight': 73,
    'StadiumRoadMainTurboLeft': 74,
    'StadiumRoadMainTurboRight': 75,
    'StadiumRoadMainTurboRouletteLeft': 76,
    'StadiumRoadMainTurboRouletteRight': 77,
    'StadiumRoadTiltCorner': 78,
    'StadiumRoadTiltGTCurve2': 79,
    'StadiumRoadTiltGTCurve3': 80,
    'StadiumRoadTiltGTCurve4': 81,
    'StadiumRoadMainGTDiag2x2Tilt': 82,
    'StadiumRoadMainGTDiag2x2TiltMirror': 83,
    'StadiumRoadMainGTDiag3x2Tilt': 84,
    'StadiumRoadMainGTDiag3x2TiltMirror': 85,
    'StadiumRoadTiltCornerDownLeft': 86,
    'StadiumRoadTiltCornerDownRight': 87,
    'StadiumRoadTiltCornerUpLeft': 88,
    'StadiumRoadTiltCornerUpRight': 89,
    'StadiumRoadTiltGTCurve2DownLeft': 90,
    'StadiumRoadTiltGTCurve2DownRight': 91,
    'StadiumRoadTiltGTCurve2UpLeft': 92,
    'StadiumRoadTiltGTCurve2UpRight': 93,
    'StadiumHolePillarTilt': 94,
    'StadiumHoleTilt': 95,
    'StadiumStretchTilt': 96,
    'StadiumBump1Tilt': 97,
    'StadiumPlatformLoopStart': 98,
    'StadiumPlatformLoopEnd': 99,
    'StadiumPlatformWallBorder': 100,
    'StadiumPlatformWall1': 101,
    'StadiumPlatformWall2': 102,
    'StadiumPlatformWall4': 103,
    'StadiumPlatformWallPub2': 104,
    'StadiumPlatformRoad': 105,
    'StadiumPlatformSlope2Straight': 106,
    'StadiumPlatformBiSlope2Start': 107,
    'StadiumPlatformBiSlope2End': 108,
    'StadiumPlatformTurbo': 109,
    'StadiumPlatformTurboDown': 110,
    'StadiumPlatformTurboLeft': 111,
    'StadiumPlatformTurboRight': 112,
    'StadiumPlatformTurboUp': 113,
    'StadiumCheckpointRingV': 114,
    'StadiumCheckpointRingHRoad': 115,
    'StadiumPlatformCheckpoint': 116,
    'StadiumPlatformCheckpointDown': 117,
    'StadiumPlatformCheckpointLeft': 118,
    'StadiumPlatformCheckpointRight': 119,
    'StadiumPlatformCheckpointUp': 120,
    'StadiumPlatformGTCurve2Wall1': 121,
    'StadiumPlatformGTCurve2Wall2': 122,
    'StadiumPlatformGTCurve2Wall4': 123,
    'StadiumPlatformGTCurve3Wall1': 124,
    'StadiumPlatformGTCurve3Wall2': 125,
    'StadiumPlatformGTCurve3Wall4': 126,
    'StadiumPlatformToRoad': 127,
    'StadiumPlatformToRoad2': 128,
    'StadiumPlatformToRoad2Mirror': 129,
    'StadiumPlatformToRoadMain': 130,
    'StadiumCircuitBorderStraight': 131,
    'StadiumCircuitBorderDiagIn': 132,
    'StadiumCircuitBorderDiagOut': 133,
    'StadiumCircuitBorderCornerIn': 134,
    'StadiumCircuitBorderCornerOut': 135,
    'StadiumCircuitBase': 136,
    'StadiumCircuitSlopeStart': 137,
    'StadiumCircuitSlopeStraight': 138,
    'StadiumCircuitSlopeEnd': 139,
    'StadiumCircuitTurbo': 140,
    'StadiumCircuitTurboLeft': 141,
    'StadiumCircuitTurboUp': 142,
    'StadiumCircuitTurboRight': 143,
    'StadiumCircuitTurboDown': 144,
    'StadiumCircuitBorderGTCurve2In': 145,
    'StadiumCircuitBorderGTCurve3In': 146,
    'StadiumCircuitBorderGTCurve4In': 147,
    'StadiumCircuitBorderGTCurve2Out': 148,
    'StadiumCircuitBorderGTCurve3Out': 149,
    'StadiumCircuitBorderGTCurve4Out': 150,
    'StadiumCircuitBorderSlopeStartLeft': 151,
    'StadiumCircuitBorderSlopeStartRight': 152,
    'StadiumCircuitBorderSlopeStraightLeft': 153,
    'StadiumCircuitBorderSlopeStraightRight': 154,
    'StadiumCircuitBorderSlopeStraightBottom': 155,
    'StadiumCircuitBorderSlopeStraightTop': 156,
    'StadiumCircuitBorderSlopeEndLeft': 157,
    'StadiumCircuitBorderSlopeEndRight': 158,
    'StadiumCircuitBorderSlopeCornerInLeftBottom': 159,
    'StadiumCircuitBorderSlopeCornerInLeftTop': 160,
    'StadiumCircuitBorderSlopeCornerInRightTop': 161,
    'StadiumCircuitBorderSlopeCornerInRightBottom': 162,
    'StadiumCircuitSlopeCornerInLeftBottom': 163,
    'StadiumCircuitBorderSlopeCornerOutLeftTop': 164,
    'StadiumCircuitBorderSlopeCornerOutRightTop': 165,
    'StadiumCircuitBorderSlopeCornerOutRightBottom': 166,
    'StadiumCircuitBorderSlopeGTCurve2InLeftBottom': 167,
    'StadiumCircuitBorderSlopeGTCurve2InLeftTop': 168,
    'StadiumCircuitBorderSlopeGTCurve2InRightTop': 169,
    'StadiumCircuitBorderSlopeGTCurve2InRightBottom': 170,
    'StadiumCircuitBorderSlopeGTCurve2OutLeftBottom': 171,
    'StadiumCircuitBorderSlopeGTCurve2OutLeftTop': 172,
    'StadiumCircuitBorderSlopeGTCurve2OutRightTop': 173,
    'StadiumCircuitBorderSlopeGTCurve2OutRightBottom': 174,
    'StadiumCircuitBorderSlopeDiagInLeftBottom': 175,
    'StadiumCircuitBorderSlopeDiagInLeftTop': 176,
    'StadiumCircuitBorderSlopeDiagInRightTop': 177,
    'StadiumCircuitBorderSlopeDiagInRightBottom': 178,
    'StadiumCircuitBorderSlopeDiagOutLeftBottom': 179,
    'StadiumCircuitBorderSlopeDiagOutLeftTop': 180,
    'StadiumCircuitBorderSlopeDiagOutRightTop': 181,
    'StadiumCircuitBorderSlopeDiagOutRightBottom': 182,
    'StadiumCircuitLoopStart': 183,
    'StadiumCircuitRampBig': 184,
    'StadiumCircuitRampSmall1x05': 185,
    'StadiumCircuitRampSmall1x1': 186,
    'StadiumCircuitHole': 187,
    'StadiumCircuitBumpUp': 188,
    'StadiumCircuitBumpUp2': 189,
    'StadiumCircuitPillar1': 190,
    'StadiumCircuitPillar2': 191,
    'StadiumCircuitPillar3': 192,
    'StadiumCircuitPillar5': 193,
    'StadiumCircuitPillar6': 194,
    'StadiumCircuitPillar7': 195,
    'StadiumRoadDirtFenceStraight': 196,
    'StadiumRoadDirtFenceCorner': 197,
    'StadiumRoadDirt': 198,
    'StadiumRoadDirtTurbo': 199,
    'StadiumRoadDirtCheckpoint': 200,
    'StadiumRoadDirtGTCurve2': 201,
    'StadiumRoadDirtGTCurve3': 202,
    'StadiumRoadDirtDiagonaleRight': 203,
    'StadiumRoadDirtDiagonaleLeft': 204,
    'StadiumRoadDirtHighFenceStraight': 205,
    'StadiumRoadDirtHighFenceCorner': 206,
    'StadiumRoadDirtHigh': 207,
    'StadiumRoadDirtHighCheckpoint': 208,
    'StadiumRoadDirtHighGTCurve3': 209,
    'BStadiumRoadDirtToRoadDirtHigh': 210,
    'StadiumRoadDirtToRoadDirtHigh2': 211,
    'StadiumRoadDirtToRoadDirtHighBridge': 212,
    'StadiumRoadDirtToRoadDirtHighCross': 213,
    'StadiumRoadDirtToRoadDirtHigh': 214,
    'StadiumRoadDirtToRoad': 215,
    'StadiumRoadDirtHillSlope2': 216,
    'StadiumRoadDirtHillSlope': 217,
    'StadiumRoadDirtHillWave': 218,
    'StadiumRoadDirtHillSlopeGT2Bis': 219,
    'StadiumRoadDirtHillSlopeGT2': 220,
    'StadiumRoadDirtWave_x2': 221,
    'StadiumRoadDirtWave_x1': 222,
    'StadiumRoadDirtToRoadGrass': 223,
    'StadiumDirtDeadendDoor': 224,
    'StadiumDirtDeadendSpot': 225,
    'StadiumDirtDeadendTent1': 226,
    'StadiumRoadDirtHillTiltStraight': 227,
    'StadiumRoadDirtHillTiltCornerIn': 228,
    'StadiumRoadDirtHillTiltCornerOut': 229,
    'StadiumRoadDirtHillTiltCornerLeft': 230,
    'StadiumRoadDirtHillTiltCornerRight': 231,
    'StadiumRoadDirtHillTiltToRoadLeft': 232,
    'StadiumRoadDirtHillTiltToRoadRight': 233,
    'StadiumSculptBridgeSuspendSlope2': 234,
    'StadiumSculptBridgeSuspendSlope2Mirror': 235,
    'StadiumSculptBridgeSuspendSlopeEnd': 236,
    'StadiumSculptBridgeSuspendSlopeEndMirror': 237,
    'StadiumSculptA': 238,
    'StadiumSculptB': 239,
    'StadiumSculptC': 240,
    'StadiumSculptArchRingEnd': 241,
    'StadiumSculptArchRingEndMirror': 242,
    'StadiumSculptArchRingStart': 243,
    'StadiumSculptArchRingStartMirror': 244,
    'StadiumSculptBridgePillar': 245,
    'StadiumSculptBridgePillarMirror': 246,
    'StadiumSculptBridgeSlopeStart': 247,
    'StadiumSculptBridgeSlopeStartMirror': 248,
    'StadiumSculptBridgeSlopeEnd': 249,
    'StadiumSculptBridgeSlopeEndMirror': 250,
    'StadiumSculptBridgeStraight': 251,
    'StadiumSculptBridgeStraightSmall': 252,
    'StadiumTubePillarCap': 253,
    'StadiumTubeV1': 254,
    'StadiumTubeV4': 255,
    'StadiumTubeV8': 256,
    'StadiumTube': 257,
    'StadiumTubePillar': 258,
    'StadiumTubePillarBranch': 259,
    'StadiumTubeRoad': 260,
    'StadiumTubeRoadDown': 261,
    'StadiumTubeRoadUp': 262,
    'StadiumTubeRoadCross': 263,
    'StadiumControlRoadGlass': 264,
    'StadiumControlRoadPub': 265,
    'StadiumControlRoadCamera': 266,
    'StadiumControlCameraPub': 267,
    'StadiumControlLight': 268,
    'StadiumControlLightBase': 269,
    'StadiumTubeRoadLightSystem': 270,
    'StadiumTubeRoadSoundSystem': 271,
    'StadiumFabricStraight1x1': 272,
    'StadiumFabricPillarAir': 273,
    'StadiumFabricCornerIn': 274,
    'StadiumFabricPillarCornerInAir': 275,
    'StadiumFabricCornerOut': 276,
    'StadiumFabricPillarCornerOut': 277,
    'StadiumFabricCross1x1': 278,
    'StadiumFabricCross3x3': 279,
    'StadiumFabricCross3x3Screen': 280,
    'StadiumFabricPillarAirScreen': 281,
    'StadiumInflatableSupport': 282,
    'StadiumInflatablePillar': 283,
    'StadiumInflatableTube': 284,
    'StadiumInflatableAdvert': 285,
    'StadiumAirship': 286,
    'StadiumInflatableCastle': 287,
    'StadiumInflatableCastleDoor': 288,
    'StadiumInflatableCastleBig': 289,
    'StadiumInflatableCactus': 290,
    'StadiumInflatableSnowTree': 291,
    'StadiumInflatablePalmTree': 292,

    # TM2 Stadium specifc blocks
    'StadiumRoadMainBirds': 293,
    'StadiumGrassBirds': 294,
    'StadiumRoadMainInBeam': 295,
    'StadiumRoadMainXBeam': 296,
    'StadiumRoadMainFWSlope': 297,
    'StadiumRoadMainInBeamSlope': 298,
    'StadiumRoadMainXBeamSlope': 299,
    'StadiumRoadMainTiltStraightBirds': 300,
    'StadiumRoadMainFWTilt': 301,
    'StadiumRoadMainInBeamTilt': 302,
    'StadiumRoadMainXBeamTilt': 303,
    'StadiumRoadMainSlopeBase1x2': 304,
    'StadiumBump1InGround': 305,
    'StadiumPlatformWallCheckpointH': 306,
    'StadiumPlatformWallCheckpointV': 307,
    'StadiumPlatformWall1Birds': 308,
    'StadiumPlatformFW': 309,
    'StadiumPlatformFWSlope2': 310,
    'StadiumPlatformMultilap': 311,
    'StadiumPlatformGridCheckpoint': 312,
    'StadiumPlatformGridFW': 313,
    'StadiumPlatformGridStraight': 314,
    'StadiumPlatformGridTurbo': 315,
    'StadiumPlatformGridStraightBirds': 316,
    'StadiumCheckpointRing2x1V': 317,
    'StadiumCheckpointRing2x1H': 318,
    'StadiumCircuitToRoadMain': 319,
    'StadiumCircuitFreeWheeling': 320,
    'StadiumCircuitFreeWheelingSlope2Air': 321,
    'StadiumRoadDirtGTCurve4': 322,
    'StadiumRoadDirtStartFinishLine': 323,
    'StadiumRoadDirtMultiLap': 324,
    'StadiumRoadDirtStraightBirds': 325,
    'StadiumRoadDirtHighMultiLap': 326,
    'StadiumRoadDirtHighDTCurve4': 327,
    'StadiumRoadDirtHighFenceStraightBirds': 328,
    'StadiumTrenchStraight': 329,
    'StadiumTrenchStraightTunnel': 330,
    'StadiumTrenchCorner': 331,
    'StadiumTrenchCross': 332,
    'StadiumTrenchCrossTunnel': 333,
    'StadiumTrenchGTCurve2': 334,
    'StadiumTrenchGTCurve3': 335,
    'StadiumTrenchGTCurve3Tunnel': 336,
    'StadiumTrenchGTCurve2Tunnel': 337,
    'StadiumTrenchCheckpoint': 338,
    'StadiumTrenchMultiLap': 339,
    'StadiumTrenchFreeWheeling': 340,
    'StadiumTrenchStraightScreen': 341,
    'StadiumTrenchInPillar': 342,
    'StadiumTrenchToRoadMain': 343,
    'StadiumTrenchToRoadMainBiSlopeStart': 344,
    'StadiumTrenchXRoadMain': 345,
    'StadiumTrenchToRoadDirt': 346,
    'StadiumTrenchToRoadDirtX2': 347,
    'StadiumTrenchToPlatformBiSlopeStart': 348,
    'StadiumTrenchToLoopStart': 349,
    'StadiumPodium': 350,
    'StadiumDecoTowerCore6': 351,
    'StadiumDecoTowerCore': 352,
    'StadiumDecoTowerTowerBeam': 353,
    'StadiumDecoTowerTowerA': 354,
    'StadiumDecoTowerTowerB': 355,
    'StadiumDecoTowerTowerD': 356,
    'StadiumDecoTowerTowerC': 357,

    # TODO: sort this out
    'StadiumRoadDirtHighToRoad': 358,
    'StadiumDirtHill': 359,
    'StadiumPlatformBiSlope2StartSmall': 360,
    'StadiumWaterClip': 361,
    'StadiumDirtClip': 362,
    'StadiumGrass': 363,
}
