LAGOON_BLOCKS = {
    'RoadMainSmall': 1,
    'RoadMain': 2,
    'RoadMainStart': 3,
    'RoadMainCheckpoint': 4,
    'RoadMainFinish': 5,
    'RoadMainMultilap': 6,
    'RoadMainTurbo': 7,
    'RoadMainTurbo2': 8,
    'RoadMainFW': 9,
    'RoadMainToll2': 10,
    'RoadMainToll3': 11,
    'RoadMainObstacleBump': 12,
    'RoadMainRamp': 13,
    'RoadMainRamp2': 14,
    'RoadMainBirds': 15,
    'RoadMainFreeSidewalk': 16,
    'RoadMainGTCurve2': 17,
    'RoadMainGTCurve3': 18,
    'RoadMainGTDiag2': 19,
    'RoadMainGTDiag2Mirror': 20,
    'RoadMainGTDiag3': 21,
    'RoadMainGTDiag3Mirror': 22,
    'RoadMainYShapedDiag': 23,
    'RoadMainYShapedCurve': 24,
    'RoadMainSlopeBase': 25,
    'RoadMainSlopeBase2': 26,
    'RoadMainBiSlopeStart': 27,
    'RoadMainBiSlopeEnd': 28,
    'RoadMainSlopeUTop': 29,
    'RoadMainSlopeUBottom': 30,
    'RoadMainSlopeBaseGT2Mirror': 31,
    'RoadMainSlopeBaseGT2': 32,
    'RoadMainSlopeStraight': 33,
    'RoadMainCheckpointUp': 34,
    'RoadMainCheckpointDown': 35,
    'RoadMainTurboUp': 36,
    'RoadMainTurboDown': 37,
    'RoadMainTurbo2Up': 38,
    'RoadMainTurbo2Down': 39,
    'RoadMainFWSlope': 40,
    'RoadMainBridgeOnSeaCliff13': 41,
    'RoadMainBridgeOnLandCliff12': 42,
    'RoadMainBridgeOnHill6': 43,
    'RoadMainBridgeOnHill': 44,
    'RoadMainSlopeBase2Hill': 45,
    'RoadMainBridgeOnBeach': 46,
    'ArenaToRoadMain': 47,
    'RoadThemeParkToRoadMain': 48,
    'HighWayToRoadMainSlope2Start': 49,
    'HighWayToRoadMainSlope2Start2x1': 50,
    'HighWayToRoadMainSlope2End': 51,
    'HighWayToRoadMainSlope2End2x1': 52,
    'HighWaySlope2UTop': 53,
    'HighWaySlope2UBottom': 54,
    'HighWaySlope2LoopLeft': 55,
    'HighWaySlope2LoopRight': 56,
    'HighWaySlope2Straight': 57,
    'HighWaySlope2CheckpointUp': 58,
    'HighWaySlope2CheckpointDown': 59,
    'HighWaySlope2TurboUp': 60,
    'HighWaySlope2TurboDown': 61,
    'HighWaySlope2Turbo2Up': 62,
    'HighWaySlope2Turbo2Down': 63,
    'HighWaySlope2-FW': 64,
    'HighWaySlope2CornerDownLeft': 65,
    'HighWaySlope2CornerDownRight': 66,
    'HighWaySlope2CornerUpLeft': 67,
    'HighWaySlope2CornerUpRight': 68,
    'HighWaySlope2GTCurve2DownLeft': 69,
    'HighWaySlope2GTCurve2DownRight': 70,
    'HighWaySlope2GTCurve2UpLeft': 71,
    'HighWaySlope2GTCurve2UpRight': 72,
    'HighWaySlope2ExchangeGTCurve2UpLeft': 73,
    'HighWaySlope2ExchangeGTCurve2UpRight': 74,
    'HighWaySlope2ExchangeGTCurve2DownLeft': 75,
    'HighWaySlope2ExchangeGTCurve2DownRight': 76,
    'HighWayTilt2Straight': 77,
    'HighWaySlope2CheckpointLeft': 78,
    'HighWaySlope2CheckpointRight': 79,
    'HighWaySlope2TurboLeft': 80,
    'HighWaySlope2TurboRight': 81,
    'HighWaySlope2Turbo2Left': 82,
    'HighWaySlope2Turbo2Right': 83,
    'HighWaySlope2-FWTilt': 84,
    'FreeWay': 85,
    'FreeWayStart': 86,
    'FreeWayCheckpoint': 87,
    'FreeWayFinish': 88,
    'FreeWayMultilap': 89,
    'FreeWayTurbo': 90,
    'FreeWayTurbo2': 91,
    'FreeWayFW': 92,
    'FreeWayBirds': 93,
    'FreeWayRamp': 94,
    'FreeWayRamp2': 95,
    'FreeWayCornerSign': 96,
    'FreeWayGTCurve2': 97,
    'FreeWayGTCurve3': 98,
    'FreeWayGTDiag2': 99,
    'FreeWayGTDiag2Mirror': 100,
    'FreeWayGTDiag3': 101,
    'FreeWayGTDiag3Mirror': 102,
    'FreeWayYShapedDiag': 103,
    'FreeWayYShapedCurve': 104,
    'FreeWayTransitionToRoadMainStraight': 105,
    'FreeWayTransitionToRoadMainSlopeBase': 106,
    'FreeWayTransitionToRoadMainSlopeBase2': 107,
    'FreeWayTransitionToRoadMainBiSlopeStart': 108,
    'FreeWayHillStraight': 109,
    'RoadThemePark': 110,
    'RoadThemeParkGTCurve2': 111,
    'RoadThemeParkGTDiag2': 112,
    'RoadThemeParkGTDiag2Mirror': 113,
    'RoadThemeParkStart': 114,
    'RoadThemeParkCheckpoint': 115,
    'RoadThemeParkFinish': 116,
    'RoadThemeParkMultilap': 117,
    'RoadThemeParkTurbo': 118,
    'RoadThemeParkTurbo2': 119,
    'RoadThemeParkFreeWheeling': 120,
    'ArenaToRoadThemeParkUp': 121,
    'RoadThemeParkTwistRoadtoWall2': 122,
    'RoadThemeParkTwistRoadtoWall2Mirror': 123,
    'RoadThemeParkTwistRoadtoWallGT2': 124,
    'RoadThemeParkTwistRoadtoWallGT2Mirror': 125,
    'RoadThemeParkLoopInStart': 126,
    'RoadThemeParkLoopInEnd': 127,
    'RoadThemeParkLoop': 128,
    'RoadThemeParkLoopMirror': 129,
    'RoadThemeParkWall-Straight': 130,
    'RoadThemeParkWall-Checkpoint': 131,
    'RoadThemeParkWall-FreeWheeling': 132,
    'RoadThemeParkWall-EndLeft': 133,
    'RoadThemeParkWall-EndRight': 134,
    'RoadThemeParkWallGTDiag2': 135,
    'RoadThemeParkWallGTDiag2Mirror': 136,
    'RoadThemeParkWallLoopIn': 137,
    'RoadThemeParkWallLoopOut': 138,
    'RoadThemeParkWallLoop': 139,
    'RoadThemeParkWallLoopMirror': 140,
    'RoadThemeParkWall-StraightUp': 141,
    'RoadThemeParkWall-CheckpointUp': 142,
    'RoadThemeParkWall-FreeWheelingUp': 143,
    'RoadThemeParkWall-StraightUp2': 144,
    'RoadThemeParkWall-StraightUp1': 145,
    'RoadThemeParkWall-EndUp': 146,
    'RoadThemeParkWall-Cross': 147,
    'RoadThemeParkWallUpGTDiag2': 148,
    'RoadThemeParkWallUpGTDiag2Mirror': 149,
    'RoadThemeParkWall-CornerDown': 150,
    'RoadThemeParkWall-CornerDownMirror': 151,
    'RoadThemeParkWall-CornerUp': 152,
    'RoadThemeParkWall-CornerUpMirror': 153,
    'RoadThemeParkWall-GTCurve2Down': 154,
    'RoadThemeParkWall-GTCurve2DownMirror': 155,
    'RoadThemeParkWall-GTCurve2Up': 156,
    'RoadThemeParkWall-GTCurve2UpMirror': 157,
    'RoadThemeParkTwistWallUp2': 158,
    'RoadThemeParkTwistWallUp2Mirror': 159,
    'RoadThemeParkTwistWallDownGT2': 160,
    'RoadThemeParkTwistWallDownGT2Mirror': 161,
    'RoadThemeParkTwistWallUpGT2': 162,
    'RoadThemeParkTwistWallUpGT2Mirror': 163,
    'RoadThemeParkLoopOutStart': 164,
    'RoadThemeParkLoopOutEnd': 165,
    'RoadThemeParkTwistWalltoFlip2': 166,
    'RoadThemeParkTwistWalltoFlip2Mirror': 167,
    'RoadThemeParkTwistWalltoFlipGT2': 168,
    'RoadThemeParkTwistWalltoFlipGT2Mirror': 169,
    'RoadThemeParkSuperLoopOutEnd': 170,
    'RoadThemeParkSuperLoopOutStart': 171,
    'RoadThemeParkWallSuperLoopOut': 172,
    'RoadThemeParkSuperTwistRoadtoWall2': 173,
    'RoadThemeParkSuperTwistRoadtoWall2Mirror': 174,
    'RoadThemeParkSuperTwistWallUp2': 175,
    'RoadThemeParkSuperTwistWallUp2Mirror': 176,
    'RoadThemeParkSuperTwistWalltoFlip2': 177,
    'RoadThemeParkSuperTwistWalltoFlip2Mirror': 178,
    'RoadThemeParkFlip': 179,
    'RoadThemeParkFlipFinish': 180,
    'RoadThemeParkFlip-Checkpoint': 181,
    'RoadThemeParkFlip-Turbo': 182,
    'RoadThemeParkFlip-Turbo2': 183,
    'RoadThemeParkFlip-FreeWheeling': 184,
    'RoadThemeParkFlipGTCurve2': 185,
    'RoadThemeParkFlipGTDiag2': 186,
    'RoadThemeParkFlipGTDiag2Mirror': 187,
    'ArenaBase': 188,
    'ArenaStart': 189,
    'ArenaCheckpoint': 190,
    'ArenaCheckpointX2': 191,
    'ArenaMultilap': 192,
    'ArenaMultilapX2': 193,
    'ArenaFinish': 194,
    'ArenaFinishX2': 195,
    'ArenaTurbo': 196,
    'ArenaTurbo2': 197,
    'ArenaFW': 198,
    'ArenaSlopeBase': 199,
    'ArenaSlopeBaseSupport': 200,
    'ArenaSlope2Start': 201,
    'ArenaSlope2StartSupport': 202,
    'ArenaSlope2End': 203,
    'ArenaSlope2EndSupport': 204,
    'ArenaSlope2CornerIn': 205,
    'ArenaSlope2GTCurve2': 206,
    'ArenaSlope2GTCurve3': 207,
    'ArenaSlope2Twist2Left': 208,
    'ArenaSlope2Twist2Right': 209,
    'ArenaSlope2Twist3Left': 210,
    'ArenaSlope2Twist3Right': 211,
    'ArenaSlope2Straight': 212,
    'ArenaSlope2StraightSupport': 213,
    'ArenaCheckpointUp': 214,
    'ArenaCheckpointUpX2': 215,
    'ArenaCheckpointDown': 216,
    'ArenaCheckpointDownX2': 217,
    'ArenaCheckpointLeft': 218,
    'ArenaCheckpointLeftX2': 219,
    'ArenaCheckpointRight': 220,
    'ArenaCheckpointRightX2': 221,
    'ArenaTurboUp': 222,
    'ArenaTurboDown': 223,
    'ArenaTurboLeft': 224,
    'ArenaTurboRight': 225,
    'ArenaTurbo2Up': 226,
    'ArenaTurbo2Down': 227,
    'ArenaTurbo2Left': 228,
    'ArenaTurbo2Right': 229,
    'ArenaFWUD': 230,
    'ArenaFWLR': 231,
    'ArenaLoopStart': 232,
    'ArenaLoopStraight2': 233,
    'ArenaLoopEnd': 234,
    'ArenaLoopStraight2Corner': 235,
    'ArenaLoopStraight2GTCurve2': 236,
    'ArenaBorderStraight': 237,
    'ArenaBorderStraightFlip': 238,
    'ArenaLoopCheckpointH': 239,
    'ArenaLoopCheckpointHX2': 240,
    'ArenaLoopCheckpointV': 241,
    'ArenaLoopCheckpointVX2': 242,
    'ArenaSupport': 243,
    'ArenaLoopSupport': 244,
    'ArenaLoopSupport2': 245,
    'ArenaLoopAdvert2x1': 246,
    'ArenaBorderStraight_Advert2x1': 247,
    'ArenaBorderStraightFlip_Advert2x1': 248,
    'RoadTunnelStraight': 249,
    'RoadTunnelCross': 250,
    'RoadTunnelCorner': 251,
    'RoadTunnelGTCurve2': 252,
    'RoadTunnelGTCurve3': 253,
    'RoadTunnelCheckpoint': 254,
    'RoadTunnelFinish': 255,
    'RoadTunnelTurbo': 256,
    'RoadTunnelTurbo2': 257,
    'RoadTunnelFW': 258,
    'RoadTunnelSlope2Base': 259,
    'RoadTunnelSlope2Base2x1': 260,
    'RoadTunnelSlope2Base3x1': 261,
    'RoadTunnelSlope2Start': 262,
    'RoadTunnelSlope2StartX2': 263,
    'RoadTunnelSlope2End': 264,
    'RoadTunnelSlope2EndX2': 265,
    'RoadTunnelSlope2UTop': 266,
    'RoadTunnelSlope2UBottom': 267,
    'RoadTunnelSlope2Base3x1_GT3Left': 268,
    'RoadTunnelSlope2Base3x1_GT3Right': 269,
    'RoadTunnelSlope2Straight': 270,
    'RoadTunnelCheckpointUp': 271,
    'RoadTunnelCheckpointDown': 272,
    'RoadTunnelTurboUp': 273,
    'RoadTunnelTurboDown': 274,
    'RoadTunnelTurbo2Up': 275,
    'RoadTunnelTurbo2Down': 276,
    'RoadTunnelFWSlope': 277,
    'HighWayTunnel Exit2x1Land': 278,
    'HighWayTunnelSlope2Exit2x1Land': 279,
    'HighWayTunnel EntryLandHill': 280,
    'HighWayTunnel EntryLandHill6': 281,
    'HighWayTunnelEntryLandHill6_2': 282,
    'HighWayTunnelEntryLandHill6_4': 283,
    'HighWayTunnel EntryLandCliff12': 284,
    'HighWayTunnelEntryLandCliff12_2': 285,
    'HighWayTunnelEntryLandCliff12_4': 286,
    'HighWayTunnelEntryLandCliff12_6': 287,
    'HighWayTunnelEntryLandCliff12_8': 288,
    'HighWayTunnelEntryLandCliff12_10': 289,
    'HighWayTunnelEntryLandSeaCliff13_1': 290,
    'HighWayTunnelEntryLandSeaCliff13_3': 291,
    'HighWayTunnelEntryLandSeaCliff13_5': 292,
    'HighWayTunnelEntryLandSeaCliff13_7': 293,
    'HighWayTunnelEntryLandSeaCliff13_9': 294,
    'HighWayTunnelEntryLandSeaCliff13_11': 295,
    'DecoTreeBeach': 296,
    'DecoBeachMangrove': 297,
    'DecoTreeBeachDeadend3x2': 298,
    'DecoTreeBeachDeadend3x2In': 299,
    'DecoTreeBeachGT2In': 300,
    'DecoTreeBeachGT2out': 301,
    'DecoTreeBeachGT3In': 302,
    'DecoBeachSandbar2x1Mirror': 303,
    'DecoBeachSandbar2x1': 304,
    'DecoBeachGTDiag3Mirror': 305,
    'DecoBeachGTDiag3': 306,
    'BeachGT2RacingOut': 307,
    'DecoBeachGTDiag3RacingMirror': 308,
    'DecoBeachGTDiag3Racing': 309,
    'DecoBeachBase5-2x1Mirror': 310,
    'DecoBeachBase5-2x1': 311,
    'DecoBeach-Ramp': 312,
    'DecoBeach-RampMirror': 313,
    'DecoBeach-Ramp2': 314,
    'DecoBeach-Ramp2Mirror': 315,
    'BeachCheckPointLeft': 316,
    'BeachCheckPointRight': 317,
    'FreeWayToBeachDiag3X2': 318,
    'FreeWayToBeachDiag3X2Mirror': 319,
    'FreeWayToBeachGTCurve3In': 320,
    'FreeWayToBeachGTCurve3InMirror': 321,
    'FreeWayToBeachGTCurve3Out': 322,
    'FreeWayToBeachGTCurve3OutMirror': 323,
    'DecoTreePalmBig': 324,
    'DecoTreeJungle': 325,
    'DecoTerraformingHD': 326,
    'FieldLandHill6GT3': 327,
    'DecoBirds': 328,
    'LandCheckpoint': 329,
    'LandHillCheckpointUp': 330,
    'LandHillCheckpointDown': 331,
    'LandHillCheckpointLeft': 332,
    'LandHillCheckpointRight': 333,
    'DecoHotelB_2x1': 334,
    'DecoHotelC_2x1': 335,
    'DecoHotelD_2x1': 336,
    'Resort2x2_InDecoHotelC': 337,
    'DecoResortBeach-Deadend': 338,
    'DecoResortBeach-DeadendPool': 339,
    'DecoCityPodium': 340,
    'PodiumResort': 341,
    'DecoCity_Support': 342,
    'DecoWheel': 343,
    'DecoWheelDiag': 344,
    'DecoCityFloorBase': 345,
    'LandToCityStraight': 346,
    'LandToCityCornerIn': 347,
    'LandToCityCornerOut': 348,
    'LandToCityBase5': 349,
    'DecoCityCheckpoint': 350,
    'DecoCityFloorTurbo': 351,
    'DecoCityFloorTurbo2': 352,
    'DecoCityFloorFW': 353,
    'RoadMainToCity': 354,
    'DecoCityFloorSlopeStraight': 355,
    'DecoCityFloorSlopeLiteStraight': 356,
    'DecoCityFloorSlopeCornerIn': 357,
    'DecoCityFloorSlopeLiteCornerIn': 358,
    'DecoCityFloorSlopeCornerOut': 359,
    'DecoCityFloorSlopeLiteCornerOut': 360,
    'DecoCityFloorRampCenter': 361,
    'DecoCityFloorRamp2Center': 362,
    'DecoCityGardenBase': 363,
    'DecoCityGardenCornerIn': 364,
    'DecoCityGardenCornerOut': 365,
    'DecoCityGardenBorderStraight': 366,
    'DecoCityGardenBorderCornerIn': 367,
    'DecoCityGardenBorderCornerOut': 368,
    'DecoCityGardenBorderRampStraight': 369,
    'DecoCityGardenRampCornerIn': 370,
    'DecoCityGardenSlopeStraight': 371,
    'DecoCityGardenSlopeLiteStraight': 372,
    'DecoCityGardenSlopeCornerIn': 373,
    'DecoCityGardenSlopeLiteCornerIn': 374,
    'DecoCityGardenSlopeCornerOut': 375,
    'DecoCityGardenSlopeLiteCornerOut': 376,
    'AdPanel': 377,
    'TechLight': 378,
    'CellTowerTall': 379,
    'CellTowerMedium': 380,
    'CellTowerSmall': 381,
    'DecoShipBack': 382,
    'DecoShipBackMirror': 383,
    'DecoShipFront': 384,
    'DecoShipFrontMirror': 385,
    'DecoShipMid': 386,
    'CE_ShipMidXBeachGT2': 387,
    'CE_ShipMidXBeachGT2Mirror': 388,
    'DecoShipMidContainerCenterMirror': 389,
    'DecoShipMidContainerCenter': 390,
    'DecoShipMidContainerDouble': 391,
    'DecoShipMidContainerDoubleMirror': 392,
    'CE_ShipMidContainerLeft': 393,
    'CE_ShipMidContainerLeftMirror': 394,
    'CE_ShipMidContainerRight': 395,
    'CE_ShipMidContainerRightMirror': 396,
}