VALLEY_BLOCKS = {
    'Road2Way': 1,
    'Road2WayStart': 2,
    'Road2WayCheckpoint': 3,
    'Road2WayFinish': 4,
    'Road2WayMultilap': 5,
    'Road2WayWithBirds': 6,
    'Road2WayWithoutPole': 7,
    'RailTrackXRoad2Way': 8,
    'Road2Way_Straight_InViaduc': 9,
    'Road2WayStraightSupport': 10,
    'Road2WayGTCurve2': 11,
    'Road2WayGTCurve3': 12,
    'Road2WayGTCurve4': 13,
    'Road2WayDiag2Mirror': 14,
    'Road2WayDiag2': 15,
    'Road2WayDiag3Mirror': 16,
    'Road2WayDiag3': 17,
    'Road2WayDiag4Mirror': 18,
    'Road2WayDiag4': 19,
    'Road2WayBiSlope': 20,
    'Road2WayBiSlopeStart': 21,
    'Road2WayCliff2Straight3': 22,
    'Road2WayCliff2Straight3_HillsLeft': 23,
    'Road2WayCliff2Straight3_HillsRight': 24,
    'Road2WaySlopeStraight': 25,
    'Road2WayBiSlopeEnd': 26,
    'Road2WaySlopeUTopAir': 27,
    'Road2WaySlopeUBottomGround': 28,
    'Road2WayCheckpointSlopeUp': 29,
    'Road2WayCheckpointSlopeDown': 30,
    'Road2WayCliff2Curve3_Left': 31,
    'Road2WayCliff2Curve3_Right': 32,
    'Road2WayCliff2Curve3In_HillsLeft': 33,
    'Road2WayCliff2Curve3In_HillsRight': 34,
    'Road2WayCliff2Curve3Out_HillsLeft': 35,
    'Road2WayCliff2Curve3Out_HillsRight': 36,
    'Road2WayGTCurve2Slope': 37,
    'Road2WayGTCurve2SlopeMirror': 38,
    'Road2WayGTCurve2SlopeStart': 39,
    'Road2WayGTCurve2SlopeStartMirror': 40,
    'Road2WayGTCurve2SlopeEnd': 41,
    'Road2WayGTCurve2SlopeEndMirror': 42,
    'Road2WayCliff4Curve3In_Left': 43,
    'Road2WayCliff4Curve3In_Right': 44,
    'Road2WayCliff4Curve3Out_Left': 45,
    'Road2WayCliff4Curve3Out_Right': 46,
    'Road2WayCliff4Side5_Left': 47,
    'Road2WayCliff4Side5_Right': 48,
    'Cliff8SlopeCorner_6x7x8': 49,
    'Cliff8SlopeCorner_6x7x8_Mirror': 50,
    'Cliff8SlopeDiag_8x3x8': 51,
    'Cliff8SlopeDiag_8x3x8_Mirror': 52,
    'Road2WayTetrisCliff3x2': 53,
    'Road2WayTetrisCliff3x2Mirror': 54,
    'Road2WaySlopeBase2x1OnHilll': 55,
    'Road2WaySlopeBaseGTCurve2OnHill': 56,
    'Road2WaySlopeBaseGTCurve2OnHillMirror': 57,
    'Road2WayTetrisHill3x2': 58,
    'Road2WayTetrisHill3x2Mirror': 59,
    'Road2WayBridgeGrassHills': 60,
    'Road2WayBridgeGrassCliff2': 61,
    'Road2WayBridgeGrassCliff4': 62,
    'Road2WayBridgeGrassCliff8': 63,
    'Road2WayTurbo': 64,
    'Road2WayTurboUp': 65,
    'Road2WayTurboDown': 66,
    'Road2WayFW': 67,
    'Road2WayFWSlope': 68,
    'Road4WayToRoad2WayStraight': 69,
    'Road4WayToRoad2WayTShaped': 70,
    'Road4WayCrossRoad2Way': 71,
    'Road4WayToRoad2WayCorner': 72,
    'Road4WayToRoad2WayCornerMirror': 73,
    'Road4WayToRoad2WayStraight2x1': 74,
    'Road4WayToRoad2WayStraight2x1Mirror': 75,
    'Road4WayToRoad2WayDiag': 76,
    'Road4WayToRoad2WayDiagMirror': 77,
    'Road4WayToRoad2WayGTCurve2': 78,
    'Road4WayToRoad2WayGTCurve2Mirror': 79,
    'Road2WayForestStraight': 80,
    'Road2WayForestCorner': 81,
    'Road2WayForestTShaped': 82,
    'Road2WayForestCross': 83,
    'Road2WayForestDeadend': 84,
    'Road2WayForestStraightNarrow': 85,
    'Road2WayForestStart': 86,
    'Road2WayForestCheckpoint': 87,
    'Road2WayForestFinish': 88,
    'Road2WayForestMultilap': 89,
    'Road2WayForestTurbo': 90,
    'Road2WayForestFW': 91,
    'Road2WayForestGTCurve2': 92,
    'Road2WayForestGTCurve3': 93,
    'Road2WayForestGTCurve3Field': 94,
    'Road2WayForestDiag2': 95,
    'Road2WayForestDiag2Mirror': 96,
    'Road2WayForestDiag3': 97,
    'Road2WayForestDiag3Mirror': 98,
    'Road2WayForestSlopeBaseOnHill': 99,
    'Road2WayForestSlopeBase2x1OnHill': 100,
    'Road2WayForestTetrisHill3x2': 101,
    'Road2WayForestTetrisHill3x2Mirror': 102,
    'Road2WayForestSlopeGTCurve2OnHillMirror': 103,
    'Road2WayForestSlopeGTCurve2OnHill': 104,
    'Road2WayForestStraightToRoadDirtLarge': 105,
    'Road2WayForestXRoadForestLarge': 106,
    'Road2WayForestStraightToRoad2Way': 107,
    'Road2WayForestSlopeStartOut': 108,
    'Road2WayForestSlopeBase2x1Out': 109,
    'Road4Way': 110,
    'Road4WayStart': 111,
    'Road4WayCheckpoint': 112,
    'Road4WayFinish': 113,
    'Road4WayMultiLap': 114,
    'Road4WayBumper': 115,
    'Road4WayStraightWithBirds': 116,
    'Road4WayStraightNoLights': 117,
    'HighwayStraightSupport': 118,
    'Road4WayGrassCliff2Straight3': 119,
    'Road4WayHillStraight2': 120,
    'Road4WaySlopeBase': 121,
    'Road4WaySlopeStraight': 122,
    'Road4wayBiSlopeStart': 123,
    'Road4WayBiSlopeEnd': 124,
    'Road4WayBiSlope': 125,
    'Road4WaySlopeUTop': 126,
    'Road4WaySlopeUBottom': 127,
    'Road4WayCheckpointUp': 128,
    'Road4WayCheckpointDown': 129,
    'Road4WayGTCurve2': 130,
    'Road4WayGTCurve3': 131,
    'Road4wayGTCurve4': 132,
    'Road4wayDiag3': 133,
    'Road4wayDiag3Mirror': 134,
    'Road4wayDiag4MirrorRoad4wayDiag4': 135,
    'Road4wayDiag4': 136,
    'Road4WayHillCurve2': 137,
    'Road4WayHillCurve2Mirror': 138,
    'Road4WayGTCurve2SlopeMirror': 139,
    'Road4WayGTCurve2Slope': 140,
    'Road4WayGTCurve3Slope': 141,
    'Road4WayGTCurve3SlopeMirror': 142,
    'Road4WayLooping': 143,
    'Road4WayLoopingMirror': 144,
    'Road4WayFreeLoopStart': 145,
    'Road4WayFreeLoopStraight': 146,
    'Road4WayFreeLoopEnd': 147,
    'Road4WayBridgeGrassHills': 148,
    'Road4WayBridgeGrassCliff2': 149,
    'Road4WayBridgeGrassCliff4': 150,
    'Road4WayBridgeGrassCliff8': 151,
    'Road4WayTurbo': 152,
    'Road4WayTurboUp': 153,
    'Road4WayTurboDown': 154,
    'Road4WayFW': 155,
    'Road4WaySlopeFW': 156,
    'Road4WayToHighway': 157,
    'Road4WayToHighwayNoSign': 158,
    'Road4WayToHighwayLeft': 159,
    'Road4WayToHighwayRight': 160,
    'HighwayStraight': 161,
    'HighwayStraightNoLights': 162,
    'HighwaySwitch': 163,
    'HighwaySwitchLeft': 164,
    'HighwaySwitchRight': 165,
    'HighwayGTCurve4': 166,
    'HighwayBiSlopeStart': 167,
    'HighwaySlopeStraight': 168,
    'HighwayBiSlopeEnd': 169,
    'HighwayBridgeGrassHills': 170,
    'HighwayBridgeGrassCliff2': 171,
    'HighwayBridgeGrassCliff4': 172,
    'HighwayBridgeGrassCliff8': 173,
    'TunnelRoad4wayStraight': 174,
    'TunnelRoad4wayCross': 175,
    'TunnelRoad4wayCorner': 176,
    'TunnelRoad4wayGTCurve2': 177,
    'TunnelRoad4wayGTCurve3': 178,
    'TunnelRoad4wayCheckpoint': 179,
    'TunnelRoad4wayFinish': 180,
    'TunnelRoad4WayTurbo': 181,
    'TunnelRoad4WayFW': 182,
    'TunnelRoad4waySlopeBase': 183,
    'TunnelRoad4waySlopeBaseX2': 184,
    'TunnelRoad4wayGTCurve3SlopeMirror': 185,
    'TunnelRoad4wayGTCurve3Slope': 186,
    'TunnelRoad4wayBiSlopeStart': 187,
    'TunnelRoad4waySlopeStraight': 188,
    'TunnelRoad4wayBiSlopeEnd': 189,
    'Road4wayUTop': 190,
    'Road4wayUbottom': 191,
    'TunnelRoad4WayCheckpointUp': 192,
    'TunnelRoad4WayCheckpointDown': 193,
    'TunnelRoad4WayTurboUp': 194,
    'TunnelRoad4WayTurboDown': 195,
    'TunnelRoad4WayFWUD': 196,
    'Road4WayEntryGrassSlopeBase2': 197,
    'TunnelEntryRoad4WayGrassCliff2': 198,
    'TunnelEntryRoad4WayGrassCliff4': 199,
    'TunnelEntryRoad4WayGrassCliff4_1': 200,
    'TunnelEntryRoad4WayGrassCliff8': 201,
    'TunnelEntryRoad4WayGrassCliff8_1': 202,
    'TunnelEntryRoad4WayGrassCliff8_2': 203,
    'TunnelEntryRoad4WayGrassCliff8_3': 204,
    'TunnelStraight': 205,
    'TunnelHighwaySwitch': 206,
    'TunnelHighwaySwitchLeft': 207,
    'TunnelHighwaySwitchRight': 208,
    'TunnelHighwayGTCurve2': 209,
    'TunnelHighwayGTCurve3': 210,
    'TunnelGTCurve4': 211,
    'TunnelRoad4wayToHighway': 212,
    'TunnelRoad4WayToHighWayLeft': 213,
    'TunnelRoad4WayToHighWayRight': 214,
    'TunnelHighwayTurbo': 215,
    'TunnelHighwayFW': 216,
    'HighwayEntryGrassSlopeBase2': 217,
    'TunnelEntryGrassCliff2': 218,
    'TunnelEntryGrassCliff4': 219,
    'TunnelEntryGrassCliff4_1': 220,
    'TunnelEntryGrassCliff8': 221,
    'TunnelEntryGrassCliff8_1': 222,
    'TunnelEntryGrassCliff8_2': 223,
    'TunnelEntryGrassCliff8_3': 224,
    'ArenaParkRoofBase': 225,
    'ArenaParkRoofBaseSupport': 226,
    'ArenaParkRoofBaseNoLights': 227,
    'ArenaCheckpointParkRoofBaseAir': 228,
    'ArenaMultilapParkRoofBase': 229,
    'ArenaParkRoofTurbo': 230,
    'ArenaParkRoofFW': 231,
    'ArenaBaseSupport': 232,
    'ArenaBase': 233,
    'ArenaBaseCornerIn': 234,
    'ArenaBaseSlopeBase': 235,
    'ArenaBaseSlopeStart': 236,
    'ArenaBaseSlopeStraight': 237,
    'ArenaBaseSlopeEnd': 238,
    'ArenaParkRoofSlopeBase': 239,
    'ArenaParkRoofSlopeStart': 240,
    'ArenaParkRoofSlopeStraight': 241,
    'ArenaParkRoofSlopeEnd': 242,
    'ArenaCheckpointParkRoofSlopeStraightUpAir': 243,
    'ArenaCheckpointParkRoofSlopeStraightDownAir': 244,
    'ArenaCheckpointParkRoofSlopeLeft': 245,
    'ArenaCheckpointParkRoofSlopeRight': 246,
    'ArenaParkRoofTurboSlopeUp': 247,
    'ArenaParkRoofTurboSlopeDown': 248,
    'ArenaParkRoofTurboSlopeLeft': 249,
    'ArenaParkRoofTurboSlopeRight': 250,
    'ArenaParkRoofFWSlopeUD': 251,
    'ArenaParkRoofFWSlopeLR': 252,
    'ArenaBorderStraight': 253,
    'ArenaBorderStraightArch': 254,
    'ArenaBorderSmallLoopStraightTop': 255,
    'ArenaBorderCornerIn': 256,
    'ArenaBorderGTCurve2In': 257,
    'ArenaBorderGTCurve3In': 258,
    'ArenaBorderCornerOut': 259,
    'ArenaBorderGTCurve2Out': 260,
    'ArenaBorderGTCurve3Out': 261,
    'ArenaSupport': 262,
    'ArenaBorderSmallStraight': 263,
    'ArenaBorderSmallStraightOpen': 264,
    'ArenaBorderSmallStraightOpenFence': 265,
    'ArenaBorderSmallCornerIn': 266,
    'ArenaBorderSmallGTCurve2In': 267,
    'ArenaBorderSmallGTCurve3In': 268,
    'ArenaBorderSmallCornerOut': 269,
    'ArenaBorderSmallGTCurve2Out': 270,
    'ArenaBorderSmallGTCurve3Out': 271,
    'ArenaBorderSmallSlopeBaseLeft': 272,
    'ArenaBorderSmallSlopeBaseRight': 273,
    'ArenaBorderSmallSlopeStartLeft': 274,
    'ArenaBorderSmallSlopeStartRight': 275,
    'ArenaBorderSmallSlopeStraightLeft': 276,
    'ArenaBorderSmallSlopeStraightRight': 277,
    'ArenaBorderSmallSlopeEndLeft': 278,
    'ArenaBorderSmallSlopeEndRight': 279,
    'ArenaParkBase': 280,
    'ArenaParkBaseGrassCenter': 281,
    'ArenaParkSlopeBase': 282,
    'ArenaBaseToParkUp': 283,
    'ArenaBaseToParkDown': 284,
    'ArenaParkBorderStraight': 285,
    'ArenaParkBorderStraightOpen': 286,
    'ArenaParkBorderGTCurve2In': 287,
    'ArenaParkBorderGTCurve3In': 288,
    'ArenaParkBorderCornerOut': 289,
    'ArenaParkBorderGTCurve2Out': 290,
    'ArenaParkBorderGTCurve3Out': 291,
    'ArenaParkRoofLoopStartSmall': 292,
    'ArenaBorderSmallLoopSmallStartRight': 293,
    'ArenaBorderSmallLoopSmallStartLeft': 294,
    'ArenaParkRoofLoopStart': 295,
    'ArenaBorderSmallLoopStartLeft': 296,
    'ArenaBorderSmallLoopStartRight': 297,
    'ArenaParkRoofLoopEndSmall': 298,
    'ArenaBorderSmallLoopSmallEndRight': 299,
    'ArenaBorderSmallLoopSmallEndLeft': 300,
    'ArenaParkRoofLoopEnd': 301,
    'ArenaBorderSmallLoopEndRight': 302,
    'ArenaBorderSmallLoopEndLeft': 303,
    'ArenaParkRoofLoopStraight1': 304,
    'ArenaParkRoofLoopStraight2': 305,
    'ArenaParkRoofLoopStraight4': 306,
    'ArenaCheckpointParkRoofLoopStraight2VAir': 307,
    'ArenaCheckpointParkRoofLoopStraight4HAir': 308,
    'ArenaBorderSmallLoopStraightLeft': 309,
    'ArenaBorderSmallLoopStraightRight': 310,
    'ArenaParkRoofLoop2GtCurve2': 311,
    'ArenaParkRoofLoop2GtCurve2ToPark': 312,
    'ArenaParkRoofLoop2GtCurve2ToRubber': 313,
    'ArenaScreenParkRoofLoopStraight1': 314,
    'ArenaScreenBaseX1': 315,
    'ArenaScreenBaseX4': 316,
    'ArenaScreenBorderSmallStraightOpen': 317,
    'ArenaBorderSmallStraight': 318,
    'ArenaBaseToRoad4Way': 319,
    'ArenaParkToRoad4Way': 320,
    'ArenaParkRoofToRoad4Way': 321,
    'ArenaBorderToRoad4Way': 322,
    'RoadForestLargeStraight': 323,
    'RoadForestLargeDeadend': 324,
    'RoadForestLargeStart': 325,
    'RoadForestLargeCheckpoint': 326,
    'RoadForestLargeFinish': 327,
    'RoadForestLargeMultilap': 328,
    'Road2WayXRoadForestLarge': 329,
    'RailTrackXRoadDirtLarge': 330,
    'RoadForestLargeToRoadDirt': 331,
    'RoadForestLargeCorner': 332,
    'RoadForestLargeCornerSignBarrier': 333,
    'RoadForestLargeGTCurve2': 334,
    'RoadForestLargeCross': 335,
    'RoadForestLargeDiag2': 336,
    'RoadForestLargeDiag2Mirror': 337,
    'RoadForestLargeSlope': 338,
    'RoadForestLargeSlopeX2': 339,
    'RoadForestLargeGTCurve2SlopeMirror': 340,
    'RoadForestLargeGTCurve2Slope': 341,
    'RoadForestLargeSlopeCornerUturn': 342,
    'RoadForestLargeStartLoop': 343,
    'RoadForestLargeTurbo': 344,
    'RoadForestLargeFW': 345,
    'RoadForestLargeBump': 346,
    'RoadForestLargeStraightBarrier': 347,
    'RoadForestLargeStraightObstacle': 348,
    'RoadForestLargeStraightNarrow': 349,
    'RoadForestLargeStraightWithBirds': 350,
    'RoadDirtCornerSign': 351,
    'RoadDirtGTCurve2': 352,
    'RoadDirtDiag2x2Mirror': 353,
    'RoadDirtDiag2x2': 354,
    'RoadDirtCheckpoint': 355,
    'Road2WayToRoadDirt': 356,
    'RoadDirtToFieldEntry': 357,
    'RoadDirt': 358,
    'RoadDirtNoTree': 359,
    'RoadDirt_Straight_InViaducPillar': 360,
    'RoadDirtRiverCrossStraight': 361,
    'RoadDirtRiverCrossDeepStraightx2Mirror': 362,
    'RoadDirtRiverCrossDeepStraightx2': 363,
    'RoadDirtGTCurve2Pond': 364,
    'RoadDirtGTCurve2Lake': 365,
    'RoadDirtDiag2x2PondMirror': 366,
    'RoadDirtDiag2x2Pond': 367,
    'RoadDirtDiag2x2LakeMirror': 368,
    'RoadDirtDiag2x2Lake': 369,
    'RoadDirtRiverCrossDiag3x2': 370,
    'RoadDirtRiverCrossDiag3x2Mirror': 371,
    'RoadDirtDeadendLakeJump2': 372,
    'RoadDirtDeadendLakeJump': 373,
    'RoadCliffSlopeStart': 374,
    'RoadCliffSlopeStartMirror': 375,
    'RoadCliffSlopeStartGTCurveOut': 376,
    'RoadCliffSlopeStartGTCurveOutMirror': 377,
    'RoadCliffSlopeStartGTCurveIn': 378,
    'RoadCliffSlopeStartGTCurveInMirror': 379,
    'RoadCliffSlopeEnd': 380,
    'RoadCliffSlopeEndMirror': 381,
    'RoadCliffSlopeEndGTCurveOut': 382,
    'RoadCliffSlopeEndGTCurveOutMirror': 383,
    'RoadCliffSlopeEndGTCurveIn': 384,
    'RoadCliffSlopeEndGTCurveInMirror': 385,
    'RoadCliffSlopeUTop': 386,
    'RoadCliffSlopeUTopx2': 387,
    'RoadCliffSlopeUBottom': 388,
    'RoadCliffSlopeUBottomx2': 389,
    'RoadCliffStraightBumpRight': 390,
    'RoadCliffStraightBumpLeft': 391,
    'RoadCliffUBottomGT2In': 392,
    'RoadCliffUBottomGT2Out': 393,
    'RoadCliffRoadDirtLargeArch2x1': 394,
    'RoadCliffSlopeUTopCheckPointLeft': 395,
    'RoadCliffSlopeUTopCheckPointRight': 396,
    'RoadCliffSlopeUBottomCheckPointLeft': 397,
    'RoadCliffSlopeUBottomCheckPointRight': 398,
    'RoadCliffTetrisSlopeStraight3x3': 399,
    'RoadCliffTetrisCliff3x2': 400,
    'RoadCliffTetrisCliff3x2Mirror': 401,
    'RoadCliff2TetrisGTCurve2': 402,
    'RoadCliff2TetrisGTCurve2Mirror': 403,
    'DecoCastleDeadendEntryLake': 404,
    'DecoCastleDeadendEntryRacingLake': 405,
    'DecoCastleEntryCheckPointOut': 406,
    'DecoCastleEntryCheckPointIn': 407,
    'DecoCastleBridgeLake': 408,
    'DecoCastleBridgeToRoad2WayLake': 409,
    'DecoCastleDeadendWallLake': 410,
    'DecoCastleDeadendWallRacingLake': 411,
    'DecoCastleDeadendTowerHouseLake': 412,
    'DecoCastleDeadendTowerHouseLakeMirror': 413,
    'DecoCastleDeadendWallCheckPointLeft': 414,
    'DecoCastleDeadendWallCheckPointRight': 415,
    'DecoCastleDeadendWallRacingCheckPointLeft': 416,
    'DecoCastleDeadendWallRacingCheckPointRight': 417,
    'DecoCastleCornerWallLake': 418,
    'DecoCastleCornerWallRacingLake': 419,
    'DecoCastleCornerTowerHouseRacingLake': 420,
    'DecoCastleCornerTowerHouseLake': 421,
    'DecoCastleGTCurve2WallRacingLake': 422,
    'DecoCastleCornerInWallLake': 423,
    'DecoCastleCornerInWallRacingLake': 424,
    'DecoCastleGTCurve2InWallRacingLake': 425,
    'DecoCastleDeadendWallSlopeLakeRight': 426,
    'DecoCastleDeadendWallSlopeLakeLeft': 427,
    'DecoCastleCenterLake': 428,
    'DecoCastleCenterCornerSignLake': 429,
    'DecoCastleCenterCheckpointLake': 430,
    'DecoCastleCenterMultilapLake': 431,
    'DecoCastleGardenFlowerStraightHalfLake': 432,
    'DecoCastleGardenFlowerCornerHalfOutLake': 433,
    'DecoCastleGardenFlowerCornerHalfInLake': 434,
    'DecoCastleGardenFlowerStraightHalfCheckpointLakeLeft': 435,
    'DecoCastleGardenFlowerStraightHalfCheckpointLakeRight': 436,
    'DecoCastleGardenFlowerStraightx2CheckpointLake': 437,
    'DecoCastleGardenStraightLake': 438,
    'DecoCastleGardenFlowerStraightLake': 439,
    'DecoCastleGardenCornerLake': 440,
    'DecoCastleGardenFlowerCornerLake': 441,
    'DecoCastleGardenCornerSignLake': 442,
    'DecoCastleGardenFlowerCornerSignLake': 443,
    'DecoCastleGardenDeadendLake': 444,
    'DecoCastleGardenFlowerDeadendLake': 445,
    'DecoCastleGardenCheckpointLake': 446,
    'DecoCastleGardenMultilapLake': 447,
    'ViaducStraight': 448,
    'ViaducArchStraightX3': 449,
    'ViaducArchStraightX5': 450,
    'ViaducCurve2': 451,
    'ViaducCurve3': 452,
    'ViaducCurve4': 453,
    'Viaduc_Straight_InViaduc': 454,
    'ViaducCheckpoint': 455,
    'Viaduc_SlopeBase_Air': 456,
    'Viaduc_Slope2Start_Air': 457,
    'Viaduc_Slope2Straight_Air': 458,
    'Viaduc_Slope2End_Air': 459,
    'Viaduc_SlopeBase2x1_Air': 460,
    'Viaduc_Slope2Start2x2x1_Air': 461,
    'ViaducToRoad2Way_Slope2Start2x2x1_Ground': 462,
    'ViaducToRoadForestLarge_Slope2Start2x2x1_Ground': 463,
    'Viaduc_Slope2End2x2x1_Air': 464,
    'Viaduc_Slope2UTop_Air': 465,
    'Viaduc_Slope2UBottom_Air': 466,
    'ViaducCheckpointSlopeUp': 467,
    'ViaducCheckpointSlopeDown': 468,
    'Viaduc_ToRoad2Way_Air': 469,
    'ViaducToRoad2WayGrassCliff2': 470,
    'ViaducToRoad2WayGrassCliff4': 471,
    'ViaducToRoad2WayGrassCliff8': 472,
    'ViaducToRoadDirtGrassCliff2': 473,
    'ViaducToRoadDirtGrassCliff4': 474,
    'ViaducToRoadDirtGrassCliff8': 475,
    'ViaducToRoadForestLargeGrassCliff2': 476,
    'ViaducToRoadForestLargeGrassCliff4': 477,
    'ViaducToRoadForestLargeGrassCliff8': 478,
    'RailTrackStraight': 479,
    'RailTrackSlopeBase6x1': 480,
    'RailTrackSlopeEnd6x1': 481,
    'RailTrackSlopeStart6x1': 482,
    'RailTrackSlopeStraight2x1': 483,
    'RailTrackSlopeBase3X1_GrassHill': 484,
    'RailTrackSlope2Base3X1_GrassCliff2': 485,
    'RailTrackBridgeGrassCliff2': 486,
    'RailTrackBridgeGrassCliff4': 487,
    'RailTrackBridgeGrassCliff8': 488,
    'RailTrackGTCurve2': 489,
    'RailTrackGTCurve3': 490,
    'RailTrackGTCurve4': 491,
    'RailTrackGTDiag2': 492,
    'RailTrackGTDiag2_Mirror': 493,
    'RailTrackGTDiag3': 494,
    'RailTrackGTDiag3_Mirror': 495,
    'RailTrackGTDiag4': 496,
    'RailTrackGTDiag4_Mirror': 497,
    'RailTunnel_Straight': 498,
    'RailTunnel_CheckPoint': 499,
    'RailTunnel_SlopeBase3x1': 500,
    'RailTunnel_SlopeEnd3x1': 501,
    'RailTunnel_SlopeStart3x1': 502,
    'RailTunnel_SlopeStraight2x1': 503,
    'RailTrackTunnelEntryGrassCliff2': 504,
    'RailTrackTunnelEntryGrassCliff4': 505,
    'RailTrackTunnelEntryGrassCliff8': 506,
    'RailTunnel_GTCurve2': 507,
    'RailTunnel_GTCurve3': 508,
    'RailTunnel_GTCurve4': 509,
    'RailTunnel_GTDiag2': 510,
    'RailTunnel_GTDiag2_MirrorRailTunnel_GTDiag2': 511,
    'RailTunnel_GTDiag3': 512,
    'RailTunnel_GTDiag3_Mirror': 513,
    'RailTunnel_GTDiag4': 514,
    'RailTunnel_GTDiag4_Mirror': 515,
    'DecoTreesSmall': 516,
    'DecoTreesMed': 517,
    'DecoTrees': 518,
    'DecoTerrainHD': 519,
    'Cliff8HillCorner_6x7x8': 520,
    'DecoCliff8_Arch_2x1': 521,
    'DecoBirds': 522,
    'OffRoadCheckpoint': 523,
    'OffRoadSignLeft': 524,
    'OffRoadSignRight': 525,
    'DecoFieldDeadendEntry1x1': 526,
    'DecoFieldDeadendEntry1x1B': 527,
    'DecoFieldDeadendEntry2x1': 528,
    'DecoFieldDeadendEntry2x1B': 529,
    'DecoFieldStraw': 530,
    'DecoFieldCornerEntry1x1': 531,
    'TechnicsLightsFront': 532,
    'PowerLinesStraight1x4': 533,
    'PowerLinesStraight1x4x2': 534,
    'PowerLinesStraight4x4': 535,
    'DecoAeolian': 536,
    'TechnicsScreenBig1x2Front': 537,
    'TechnicsScreen1x2': 538,
    'TechnicsScreen1x2Mirror': 539,
    'TechnicsScreenLong1x2': 540,
    'PodiumDirt': 541,
    'PodiumParking': 542,
    'DecoFarmA': 543,
    'DecoFarmB': 544,
    'DecoFarmC': 545,
    'DecoFarmD': 546,
    'DecoFarmE': 547,
    'DecoFarmF': 548,
    'DecoFarmG': 549,
    'DecoChurch': 550,
    'DecoMayorHouse': 551,
    'DecoHomeBig': 552,
    'DecoHomeBigB': 553,
    'DecoHomeSmall': 554,
    'DecoOldBusStop': 555,
    'DecoWaterBridge': 556,
    'DecoWaterMill': 557,
    'DecoHomeSmallSlopeA': 558,
}